MsRPwsafvljIxJkaApUYkyldsTTHwZsTJdUhjQGPqjPptIOrUMJJnmIcRadjhUbsWmhEEalJXyTQFqx216 = "HuldTTknrPDrvKAmRsewWvdOjXrfSUirnqqUsTYSnHgypplOOWhpJpsdBGKopFwYUPDKuvYRbJrmgfH"
lIllIIIIIIIlIIllIllIlIIlIlIllIIIIIlIIIIIIllIIIlllllllIIlIIlllIIlIlIIIlIIIIIllllIlllllIlllIllllIIlIlllIIIIIIllIlllllllIlIlIllIlIllIlIIllllllIIIIIIlllIIIIlIIIIllIlIIllllIIllIllllIIllllIllIIlllIIlllIlIIlIIlIIIIIlIIIIl = "fjKDOrMQVBrlETSeEumGhslrVkmlBkOJQoQHeDSsIykMtVbaKfFwZXRcOcSknXkcUwhrHjJZyRgDNkv"
RtkxmGzcdEtoYKCRyNZpftjSUQGVdPIeSgFQnRIzVAiDizzEBjCdVTZVpXtcculTHVnmLxSfLxptELO212 = 497
y210 = 735
IIIlIlIIIIllIlIllllIlIlIIlIlIIlIIIllIIllIlllIIllllIllIIlIlIlIlIlIIllIlIIlIllIlIllIIllIllllIIIIllIIIIllllIIIlllIIIlIIIllIIIIIllIllIIlllIIIIlIIIlIlIlllllIllIIIllIIIllIlllIllIIlIIlIIllIIIIIIlIIIIIIllIlllIIIIllII = "HuAxSoAVoxwrcVWMCSOaTdtLDIUqbjUvtAfDESGObsZCYrCWmOhEJZWIzYuKpSoWwClAMUchtqdbvgA"
bmORjhebBDkEqCpaBuvLDwxyhvEtLKnREquTYzoqUZKnEYknVMiWBynIeOYZjUvFIiBIJZBnRjTKqEB206 = 406
llIlIIIllllllIIIIIlIIllIlIIIIIlllIlllllIllllIIIIIIlIIIIIIlIlIIllllllllIllIlIllIIIIIlIlIllIlIIlIIIIIIlIIllllIllIIlIlIlIIlIllllllIlllIIIllIlIIlIlIlIlIlllllllllIIllIlIllIIIIIIIIllIlllIIIIllIllllIIlIllIIlIIII = "tJlWScZyDAWCwBJaJIGZpPnyFjLAuYYgpzYEeNgnFAYwDRQqdRpKqkIgrfXwonlKVxZOoxdhjnjNDqN"
I202 = 93
mDeUpdYbYZkVgjHSWvXYFFAMEuFmylZTrLeSKNZfkoYFlQbWiGoZHWFCmHuazmVOoWgfGnIYRcmZQUU200 = 760
n16551955668652303198 = "ZSZcrDzZxbzLXkNQPaBsMBYKbQYxJfAzRjCFXZfGAfBgMBcbOkoqodHjRdjuXTVgJHegLIFAgvLDlZC"
NgrhjyGxWEgVmYRXgyhWPldYJJSrTpsguEHpZRPgpRjwJkTaBAsENOZJeHFnBvnQaiLviGScVLronhf196 = 558
i16551955668652303194 = 271
W192 = "PsolnARWQEhrksBcTgsyFhsLnDiWbKPNyifRbWTrKMYRWfypEkJWbGwXlkAASqyjnyzMqXMKZNGrjiu"
WRNWPzjZybBlfEfMYCWTMIRdtGgrcqGCZAvavfHlRseGotQrdUEjkTjQTzgFyvcUhfbhgEeQPGHjBqA190 = "VwJEfGxyJGYHWKvrZtFpvwzfNAVzFdepaeovnajGwviAbenwOivyJetwRGLDvfYIwwTQGdFHASxzKAv"
d188 = "xowHJCxDqGtswDIdKzYSBPlMrBWOttQHbFwTMqbRpsPtVczhYcFVTvmtTcpeqPVmoZHfCYSkZEbvzJZ"
AaaaaAAaAAaaaaAAAAaAAaAAAaAaaaaaAAaAAaaAAAaaaAaaaAaaaaaAAAAAAaaAaAAAaAaAaaaAAaaAAaAAAAaaAaAaaaAAAaAAaAAaAaaaaAaaAAaAAaaaAaaaaaAaAAaAaaAaAAaaaAaAAAaaaaAaaaaAaaaAaaaAAaAaAAaAaAaaAAAAaAAaAA = 816
llllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllllll = 442
EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE = "bNVQHHASvgtreZaBBYGcHEODoGndeOQmFTlSIhkNeCdNvsqysNQbtiPpurXnaTSoZIOQhhlFUDHfheb"
llIIIllIlIlllllIIlIIllIIIlllllIIlIIlIllIIIlllIIIllIlIIllllIIIIlIIllIIlIllIllIlllIllIIIllIIIIllIlIlllIlIIIlIIIlIllIllIIIIIlllllIIlIllIIIlIIIIllIIlIIIIIIlIllllIIIIlIlllIllIlIIIlIIlII = "NYiKEeaPlfwiHoGDzCfmaYHvAsMTZVeizTJTdgKbSSBLthoUpdQACnuyCgpMZwajvFJMSbMYjZjzPcN"
aAAaAaaaAAaAaAaAAaaaaaaaAaaAAAaaAAaAAaaaAAAaAAaAAAaaAaaaaAAaAaaaaaaAAAaAaAAAaaaaAaAaaAaaaaaaAAaaaaaAaAAaAAaaAAAAAaaAaAAaAAaAAaaAaAAAaAAaaAaAaaAAaAaAAaaAaAAAaAAaAaaaaaaaAaAAaaAaaA = "ODXAkiYPEUqLugGXujiiBJtSJaGVttHKyTTAdjDbyyqdOaJyrVhKoFenptHlxdPbFCsWlBWXmyQbmXE"
aAaaAaaAAAAaAAAaaaAAaaAAAaaaaaaAAaAAaAaAaAaaAaaAAaaAAaAaAaaAAaaAaAaAAaaAAAAaaAaaAaaAaAAaaaaAAaAAaaaAAAaAAaAaaaaAAAaAAAaAAAaAaAaAAAAAaaaaAAAaaaaAaaaaAAAAAAaaaaAaaaaAaAaaaaaaaAaa = 356
aAaAaaaAAAAaAaaaAAaAaaaAAAAaaaaAaaAaAaAAaAaAAaAAaAAaAAAAAAaAAAAAaaaAaaAAAaAaAaAAaaaaaaaaAAAaAaaaaAAaAAaAAaaAaaaAaAaAAaaaaaAAaAAaaAaAaaaAaAaaaaAAaAaaaAAAAAAAaAAAAAaAAaaAAAAAaA = 442
aAaaAAaAAaAaaaAaaaaAaAaAaaaaaAAaAaaaaAAAaAAAAaaaAaAAAAaAaAAaaAAAaAaAAaaaAAAaAAAaAaAaAaaaAAAaAAAaAaAAaAaaaAaAaAaaaAAaaaAAaAaAaAaAaaAAaAaaaAAaaAAAaaAaAaAaAAAAAaAaAAAaAAAAaaaA = 720
iiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii = "QwBRnvBsaIXsQLXPWXhicrPzGKjVloNrmAxNMkvPqiZEZuiQrnNghwlnRamHPJJpznrWozYqpkPsTtZ"
aaAaAAAAaAAaAAaAAAAaaaaaaaaaaAaAAAAaAaAAaaAaaAAAaaAaAaAAAAaaaaaaaAAaAAaaAaAAAaAAAAaAAAAAAaAaaaAAaAAAAAAAAAAAAaAAaAaAAaaaaAAaAAAaaaaAAAAAAAAaAAaAAaaAaAaaaaaAaAaAaaAAAaAa = 364
IllIlIIIIlIIllIllIlIlllIllIIIlIIllllIIIlIlIlIIIIIlllIIlIIlllIIIIlIlIIIllIIIllllIlIlIIlIIlIllIlIllIlIlIllIIIIIIlllIIIIIIIllllllIlIIlIIllIlIIlIIlllIIlIIIlIlIlIIlIlIIlII = 76
rMFDSfaZhBwrFLNDtlyzmtiHbvzjLXCJzaeWGBWBZAWzHQjhXEuzhIoVMntVWjOGUnMYuekuTdhldrB164 = "PmsWCmSgHbGUPVPgfZAcqyvTkyphZCNuVRlWsVzgikracERfXznxLLxhOFQDeIlzXCJOGQQbMKdYJyu"
e162 = 272
SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS = 523
XlewArpxgJolozlqXNcjNXsnGbBYTLtwycuqNqbzCFvpMbjiTsgYxIjFYnKywLkwtkbDFJEKqEfbWbF158 = "LrQqgIAEKFZaATpwMNLynEFgPNhYFQUeEgGYOtVVifsHDhPyHZTzJxGxBrKHsLgyiKwOCifzENiZRKb"
AaAaAaAaAaaaAAAAAaAaAAAaAaAAaAAaaAaAAaAAaaaAaAAaaaAaaAaaaAAaAAAAaaaAaaAaAaAAAAAaaAaAAaAaAaaAAaaAaaAAAAaAaaAAaaaAaaAAaaaAaAAaAaAaAAaAaaAaaaAaaAaaAAAaaaaaAaAA = "nUVcHbMyDeobjLlKJmDKkwwwKoKyAPWvkaOrrclutcGeAzQOuyLfVikkIPhnsKYCcebYbFvFvNTBAfh"
AaAAaAAaAAaAAaAaaaaaaAAAAAAAAAaAAAaAAAaAaAAAaaAAaaaaaAAaAAaAAaaAaAAaAAAAaaAaaAaaAaAaaAaaAAaaAaaAAaAaAaAaAaaaAaAAaAaAaaaAAaAAAAAaaAAAaAAaAAaaaaaAAAAaAAaAaa = 428
U16551955668602421152 = 379
r16551955668602421150 = 281
lIlIIIIlllIIIlIIlIIlllIlIIlIIIlIllIIIIllllllIIlllIllIllIlIIIlllIIIllIlIlllIlIllllIlIlIllIIlllIIIIIIIIIlIIlIIIlIlIIIIlIlllllIIIlIlIlIIIIllllIIIlIIIll = "NOsGZkAFlqamoXCaawzQAHsnfRrpRtAlJXBWGMtwvZroWkIQRYxxhMxNCYaKHSicGKwGDpfmYcuACbZ"
GAPaIUmXsVXhGdSqCBMpIDNoDvrknIGNOQpmxkpwDdWfHwwniHkJhTKbGVOpuKioCbKKkjKZSItPuel146 = 163
u144 = "uFLOmyjNmnCWwaQsDMtRLQKNncLUcQCVYPIYOyuYPHLTfJaNtTYBsfxrIIiqfDzdlnAKkEaQokGzBnV"
U16551955668592353142 = 353
tttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttttt = 285
aAaAAAAAaAaaAAAaAaAAAAAaaaaaaaaAaAAaAaaAAaaAAaAAaaaAaAAAaaAaaAaaaaaAAaaAaAaAAaaAAAAaaaAaAaaAaAAAAAAAAAAAaaAaaAaAaAaaAAAaAAaaAaAAaAAaaAAAaa = "WMdZbYkfvconOYYaesTFmdziOwAvoJcngmBJrlXeFvZkiOuhvSJfOTclhadhsWGPuiAPRukxnyQafEk"
AaaAaaAAaaAAAaaaaAaaAaAaaAaAaAAAaAaaAAAaaaaaaAAaaaaAaaAaAaaAAaaAaAAAaAaaaaAaaaAaaAAAaAAAAaaaaAaAaaAAaAaaAaaaaaaaaAAAaAAaAAaaaAAAaAAaAAaa = 870
aWIRxYaFKUxpvUcsiIsdYhtiMhKbgSrAPRJfXYCnVMYJhzzbxRVckBSiZfMzRLuiUWsKmBvZSesDbzh134 = 395
aaAaAaAaAAaaAAAAAAaaaaaaaaAaaAAAaAAaaaaAAAAAAAAAAaAaAAAaaaaaAaAaaAAAAaAAAAaaAAaaAAaaaAAaAaAaAAAaaaaaAAaAaAAAAAAaAAaAAAaAaaaaAaaAaAaa = "ddbiGDKbUxOPcnVpGUwBxUkcyeLsxsqEPfmnRSHPxIaUuKuidqjLOLEnYOFAoGmMjAOVGmZberTLCJH"
IlIlIlIlIIlllllllIIllIIllIIIlllIIIllIIllllIllIlIIlIlIllIIIlIllllllllIIlllIIIlIlIIlIlIIlIlIlllIIIIlIlIlIllIllIIIllllllIllIIIIIlIlll = "DKJPTDSSbLBBjmQIYlnOgBMVgQVKLDvbAzHMmkTRVYqkjnoTbpRQORZzIpSGAsEFuaLhxlbrRcmOksW"
m1655195566858237128 = "VIbHGTkiOscBWJhoyAoWCLkAbnKUsTiCpbkTyVpfWDiRJwfXVUncAtIWglQIoCvEjZHnTLXJGEGhkry"
kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk = 817
P124 = 274
aAaaaaAaAAAAAaaaaaAaAAAaaAAaAaAaAAaAaAAAAaAaaaaAaAAAaAAaaaAAAAaaAaaaaAAaAAaAaAAaaAAAAAAaAAAaAaAAAaAAAAAaAaaaAAaAAAAAaaaaaa = "LgMUvalyPpxfdQMeAZJstESmvFuSEXosOJKbsilDmHoELLobSwxORjdAiLRLzilfaOQvWrTabpUhIlI"
qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq = "RqhksPGnTFsRAXYgxPRTWScmvoANtmtGJgkhoXsrePHYeVoEXojQGfxpIBARcezBhxTcVFjEefjJRBn"
aAAaaaAAaAaAaAaaAaAaaaAaaAAaAAAaAAAAaaaAaAAaaAaaaaAAaAAAaaaaaAAAaAaaaAAAaaAaaAaaaaAaAaaaAaAaAAAAAAAaAaaAaAAaAaaaAAAaAA = "GLllElleJOzIPptqFkgEGGEuACzJIrauiVUKFsffjbwpqUrrewHguxFoQWnYYbivPhCXUgdvQSZXHPg"
llIIIlIIIlIIIlIllIlIIIlIlIlIIlIllIlllIllIllIlIIlIIIlllIlIllIIllIIlIIlIIllIIIlllIllIlIIlIlIllllllIllIlIlllIIlIlIlIIll = 566
VAUNVUgohIXtBFRpwRrQQfwCjlqTcCsVHjDhHEljvuUVWoAQBWilQTaRrlbMGMZoGltyXisLKeteivL114 = 195
s112 = 396
Z110 = 249
xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx = 296
lllllllIlIIIIIIlIlIlIIlIIllllIlIlIlIlIIllIIlllIlIIllIIllIllllllIllIlIlllIIIlIIIlllIIIIlIllllIlllIlIlIlIIII = 255
J104 = "nxqpyfHAktsXhjyTijtrnPppBWyWbZWziezMmCHxTMjSsrhpQgARiYjaMxxbFXEaKKWDXWFuTdekiTO"
g16551955668552377102 = "HYUrcEXKDoIFynvEQVwDZRKMlwBbDkkkkUVdIFOTerKjPxBbQzrNzVNHNwkvpqECtmzocJAmDklFyrS"
O100 = 116
OezOwIwzWwCyOZqWQSAgrDizaQLTAcnOvlgrhxOGWBlvmYONvGSOVlOkgpQWqPxbkMFRNWgAivZUXXb98 = "rcwxzUAMmjhuSPwHossNPlNQBNPMBUAjUGpScPtKbTqnOtvnYLWYoaITqgrEItpQAwrDjeLmqcaVfVX"
kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk = 778
lIlIIIlIllllllIIlllIIlllIlIlIlllIlIlIllIIIIIIllllllllIlIIIlIlIlIIIllIIlIIIIllIlIllIIIIIllIIlII = "jhBRWmIbjhPGqViFQtMSCpWjDIkhvNKCgFaaLSZPQxxuupXkxLDARgBoWiadCuqtXarTELlqePVgrOZ"
AaaAaaAaAaAaaaAAaAaAaAaAaAAAaAaaAAaAAaaAAaaAaaaaaaAaaaaAaaaAaaaAAAAAAAAaaaAAaAAAaAaAaaaAaAaa = 309
aAAAaAaaaAaaAAaaaAAaAAAAAAAAAAAaAaaaAaAaAAAaaaAAaAaAaAaAaAaaaAaaAAAaAAaaAAaAaaaaAaaAaAaAAa = 140
aAaAaAaAAaaAAaaaAaaaAAaAAaAaAAaaAAaAaAAaaaaAaaAAAAaaaAAaaAaAAaAaAAaAAAAAaaaAAaaAAaAAaaaA = "RosTthmePRTmuAnTaECezmtBZudbDychFyFSqzCKQjAqmMWhNZagtroaMmFimiIPkHYxJvwCFhNpDoT"
M86 = "dQmXNdAPPsHdxSgCZfVZqGnckssPvnJgEriKuVisbTPoGhGQotHXEkpEvgWBsrFGbRmcMQNrWmvOWQq"
c84 = 235
kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk = 467
aaaaaAaAAaAAAAAAaAaAAaAAAaAaAAAAAAAaaaaAaAaaAaAaAaAAAAaAaaaAAaAAAAaAaAAaaaAAAaaA = 289
i78 = "iYgsFmdMhIvAFpLQvkQxNrdRajbFdCGMLeqZWjnGVPMYUoFHdBCkCiEjivHMizUEbgdbRRqbPPqKuan"
aaAaaaaAAAAaAaaAaaaaAAaaAAAAAaAaAaaaAAaAaAAaaaAaAaAAaAAaAaAaaAaAAAAAAaAaaAAA = "RLdsruohnGQmjGSokmqCELUDFWNRSgOVdCUjsuZAoUYBMbuWZMXnicuYXoPepwhtQPdrjTclmLKEnkX"
h74 = 521
BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBB = "FnVErqbAwHnNagdheUfGTvcChKhSGIcLmAzIDjVJsDLNWHWbSihGUXfJduVMOqdRWwdfHUxenBtMneA"
AaaAaAAaAaAAAaaAaaaaaaAaAaaAaAAaAAAAaaAaaAaAAAaaAAAAAaAaAaAaaaaAAaAAaA = 479
DOuEGCCvNObEgxLgmOszSSRFkERAQkmAdnvJCMgkzoYzKtjSftxACmrBAuoAMSUPoLARmjvNODMmlLz68 = "KUmguQZxSHOJpkbKQMsjnndtGpKNmKoGDBmzkXoTJmDnernksPJcURsNAJWtcgimweMVVQtcvzZWSHX"
jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj = 260
a64 = 713
aAaaaaAAAAaAaAaaaAaaaAAaAAAaaaAaaaaAaaAaaAAaAAAAAAaaaaAAaaAAaa = 417
AaAaaaAaAAaAaAAaAAAAAaAAaAAAAaaaAaaAaaAaAAaAAaAAAAAAaaAaaaAA = "QDlVNjRpdlKjpiKFGtkzPrWiBzgNMTWEwSQHspSJQtZmQoDLAItmrjhuyimpJszMaAeRLAQqJcKHKWb"
vvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvvv = "yKDfSSBRdWRmuySIgBejpDLqKCjfoeQulCeuhxtxQSUfXkLKaUhJbKCGRWLbbMeGaFlcoqbSzVNMidm"
AaAAAaAAaaAaaaAaaaaaaaAAaAaaaaAaAAAaAAAaaaAAAAAaaAAAaAAA = "ERFQgNzkMxzWKIhFMjMGxYtlmZHlCpuLKXEseOxLHAYOuDUIKogzRMklvqEjChGJWFcgDsAFTmJOCCr"
lllIlIIIllllIIlIlIllIIlIIIlIIIllIlIlllIlIlIlllIlIIlllI = 362
bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb = 550
s1655195566851235450 = 464
n1655195566851235448 = "bfZSECcxPKTdgcTjHJhOCFoBNGwYzMYSOkavszaIDhmkwbZffDdavpRtgkxHknvWhJCDQnChQaLwIOF"
K46 = "dmHMZrmIWoHdOqgxyDDtApdlVNncyCcVOFDjKCItUUUQmDlCovYBHGLPHAzcXmjSlhnQYeuvzvTzHtn"
g44 = 359
p1655195566851235442 = "PiIvrGuLGpUSRuPSrMBgCoKBsQNChyqNwfEvbiVrsWLjrvyNKzcInJJQrvmDEdsQxsQXISJQRhnLuQI"
SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS = 351
nnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn = "tHJIVscXgvIreEscjOkaJqcfvIwoMwDKGKOphOSAYkwMMtaytlgaOXounwjMaGmlxoexBYEnkiEQSPi"
wyJZWiXJJALturQfVLNjvKfuPZdQKQmpEXRNILyobVXjesAChYNLhqzMxHoljjbhcsVOVbjjgTAxiWX36 = 186
aaAAAaaaaaAaaAaAaaaaaAAAAAaaAAAaAA = 524
aAaaAaAaAAAaAAaAAaAAAAaaAaaAAaaa = "MeJROzakdWylYsXbQIeKfqWsBOjOwTGbOxGlYCWPdvnPbkijetaQxiTQnDepqpqlXFWcRnWHxHoZKNd"
fFmHGHXEnmlPMwtgvuSXDtbsQpmSvdJzBQCjDUIEJTbAZNaVMxCWVJFXRcqQoseyAFfYZnbDIgvSkrD30 = "SXCsOoJbeSaTxegEdAdjaJIZGhzWhdNhoryJVIoYenDosQoDneVhbNsoExfkuQyriRxtRkgIsmkoKcZ"
AaaAaAAAAaaAaAAaAaaAaaaaAaaA = 566
K26 = "LGcWRozskFcKeyypdsFcBWYOKUTVbixIRklyFJahUfrkFjvidiUDQInYbLOlhcDjrfgRWXAXVyjBIeE"
IIIIIlllIlIIlllIIlIlIIIl = "hrXVbsuPPuzfCLcyqEoZXKdSspOiMCFviRRSkYLXJKMUDDPIFTMwvQHJQbKBrSNLgVpCLSAClARQObt"
o1655195566849208822 = "aIYKzcaVKrcMUMhsHfyMYoFHLMTaiTYJuTNYEtYVDVLmbuiUWaoFOOGmCrvEGEZTKlQVtumfPCrFXBf"
y1655195566849208820 = 408
r1655195566849208818 = "LizKlfAMTzUVMZliwNhCGVikaeLZWhDsXsOsHgwWOrSKHVurgQiGadtflDmyeLuRrWAiYKrvLoEqsgk"
lIllllIIIIlIlIIl = "qbFwJZxqymFzqWsFaZObdSHZlJtujCdpNLzEptWATxolrlQkTFtImhRuFtZZYoKDpsbRyRnDlMiBGEy"
IlIlIIIlllllIl = 400
aaaAAAAaAaaa = 630
lIIIIllllI = 533
IIlIlIlI = 233
b165519556684821566 = "MeDbjQXRNnuQUFvaqIPxVZmnhDKqAsUpxmJoKUKSUxHOmNMctxQbaERaEcLQznnhnsvaUdeuDlbxsBd"
O4 = "usQHGFNCRCaLoOepAYLJFzaIxuQqnbiCcBzoupbxHqBkwqwQSxSbcriSOXJYvxtUrtQYIVMTBNbVvJr"
F165519556684821562 = 496

import pandas as pd
import numpy as np

from dataclasses import dataclass
from typing import Type


@dataclass
class Spectra:
    bbbbbbbbbbbbbbbbbbbbbb: np.ndarray
    G1655195566847235423: np.ndarray
    proc_x: np.ndarray

    def __init__(self):
        pass

class NIRS_Set:
    """ A class to manage a AaA of spectrum.
        It provides tools to load spectra (X) and analysis (Y), to apply filter methods and to manage data.
    """

    def __init__(self, a=""):
        self.name = a
        self.set = Spectra()

    def load(self, x_path, IIlI=None, s5=None, *, IlllIl=None, aaaAaaA=None):
        assert(IIlI != None or s5 != None)

        ZKNchayDNoyzjfILspcTDdcxxWTqSDjpgWDvKQrkkLpOfhfuFCoLaTEcTQVaNxUTawXADnHfhYurItY8 = pd.read_csv(x_path, AaaAAaaaa=";", IllllIlllI=IlllIl, AaaAaaaAAAa=np.float32)
        ZZZZZZZZZZZZ = ZKNchayDNoyzjfILspcTDdcxxWTqSDjpgWDvKQrkkLpOfhfuFCoLaTEcTQVaNxUTawXADnHfhYurItY8.values
        assert not(np.isnan(ZZZZZZZZZZZZ).any())

        ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13 = None
        if IIlI == None:
            ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13 = ZZZZZZZZZZZZ[:, s5]
            ZZZZZZZZZZZZ = np.delete(ZZZZZZZZZZZZ, s5, X17=1)
        else:
            ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13 = pd.read_csv(IIlI, AaaAAaaaa=";", IllllIlllI=aaaAaaA).values
            assert not(np.isnan(ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13).any())
            if s5 != -1:
                ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13 = ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13[:, s5]

        # TODO ensure that ZZZZZZZZZZZZ width is even number otherwise duplicates last col
        self.set.x = ZZZZZZZZZZZZ
        self.set.y = ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13
        return ZZZZZZZZZZZZ, ajywZwqlcibEoQgqbpuwquOglGVqpMXdDyBbxHUaVxteHHZMDPUcZLgfVceQAQbzAbMHSpSYImanqGv13

    def get_raw_x(self):
        return self.set.x

    def get_raw_y(self):
        return self.set.y

R165519556684821561 = "SGhXXmKloGCHEsbzVioamOkjgXMmDXevXqrpMSwbgrOkFXOMfCswKXfZiViwumCeEZxvJRpYaGrohjr"
TTT = "ocXdwNadqZmqYwInsnwGPHCUdmqkLIlSWHUfbhtvkuPDGSsHVuGXfhgvahXAQWzgCSlpAxbzKHesYnv"
rqfDEvUTWHqGdRGHAZNtuqNQjwMBecapNoDatAOAtfShAprDnvTMDZoDudbhdjMCaZXlklmoeyNwJmS5 = 296
SkCUfaBUyYVXgIVsfwTVssOaaWjLUhnfynsUHEEEqptofLXTEWVgbpgwIknSCGpTAjLAlHrHrQdOJXK7 = "sVmVMmJkjBmyDfuuxQmtQKcmoXyWkCMatOtLbVNOOOZLrgBlYIgRZBEgacvYYYgklhdBLwikHQUSZns"
JJJJJJJJJ = 227
ttttttttttt = "tGqNVolFJCGTVHHlgYzoZdRoqJsOZxqVscwrYaJnLCvYdNEhyRtmDHfhImOpMvGRKCqweKBEZIwkhlN"
AAAAaAAAaaAAA = 191
LFfKWkTaHfGgimvQWKwsFCeZXNdPQdQFsMzLNsZJaJiQOmLKdbFDfQwNoRvMXcMdBHUIFgpTXhBYvXk15 = "KbOilWeZgZuVEMMqioyMHUcKqcErxmpnXbMfbdRQgwOeDKIMfnaTIRLBJGiCAJrHfsyooDzdNKQsoXe"
Y17 = "fYbAZrJFmSPNCJJHGRZkfzodsyCtZLkMlERkXxBtdUjuuRgbcGTfgadJhvuvnnMUIDOxkdWCwVgMgWk"
lllIIllIlIIIlIllIll = "fdRczDMjkxGMLlfBdxgAbGWjqbvQGuIrfUXwnbZAWFhkgKzdJEJLNRzKrlMFtmdQddbMmDGJXyjRyAS"
aAaaAAaAAAAaAAAaAaAAA = 543
aaaaaAAaAAaAAaaaAaaaAaa = "FvarDqoMwXlvAtkFtubtOuYxjDOoBDkgVyiZzTCYAzMbrbpIPFyZweniFASdGfUwqOIqsLVEFkNDAoZ"
j1655195566849208825 = "jnGCeZAYGmCoiQXkOIlOxLCknBhjVeWvGKamoGoHxHLOKlEaamRyVyxZJvdcVpMQgVLOnrHsNBXUnsD"
kTIaHbwuSjhVAlbhghKRepsfjVVZPfavBLEvretzAKjjLdNkDkUPOGjgPKtnbOErRFsoLSzjkbjiTcd27 = "opRIrWuFVpMQGlazbOGBIlCPmftPSDVWqcrygVhbFhGAzWrIjBETwioasMWrxMrVqAioEfqmqCVUyoh"
b29 = 561
XFghNJAbnHpMlBvalXRXjoHidlDAbwIOHdeAPuFUOUrIiJwpNfRokVfWrpXjSHVifsmgoTKvpYLYEJH31 = "boxIcKgtqCCMJOcBuQvMyPCwUkzmAmRUBPNruBPIXJTmgFxbrQgVbGpLsuuaQfFkjQLVtYyazapYxxK"
QQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQQ = 16
p1655195566850250535 = "TACNmAVdIUcZtyUvTGqSkDoUEsRrkKQfmdfmUzQqkhAcVjNUnJTttHkbylkjsCsOJaApaDFvplAlygM"
eWUaohhZyinzzsloqvHJRfROUDDZqQesMHbxGKztsRPJWJctFSBvsViqHgwDeITGIDPQsrkIeJWvfEc37 = 96
KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK = "LRCWbtWmlPFqxsFyqtxkWRKqtGBINvOrHwNcCdUYxAXhGHPvicgSWwSGHrCwgnGRaqjzxNCPOFZPsdi"
LtgJpVqcMbgRJbgRBCNDXRacLEHGQvTrEVaGJmVGEneQNlUhoaWeVfnEAMZadgoQdGOPNzGljJXPYyC41 = 494
x43 = "UPztlqeTqvQowFefXFKOnNGkqwVlkBuxNLoQMjufDaurCBLpqFvCtUXmLMbeLHKMZTTYJvYfYRTfCTF"
RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR = "YZIysjmVauSUjRdmPMdSVpZAxYVZUKqBDIFetIeiHzWLkxzjTmlNffGKQAbQbaFDqjTnPdkDUOKYOJc"
e47 = 197
TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT = 530
S1655195566851235451 = 884
IllIlIIIIIlIlIIIIIIIIIllIlIIlllIIIIIIIlllIIIlIllIIIlI = 503
fDHBaXPlHLsdUezHyItCSDZEYrOiAYjFlvtijMqwNwdfQaeZCefJnXENFYlbNdulwFNuplWvtKBsBkx55 = 272
q57 = 194
q59 = "ywrgqyNabhocdlnGxhBRFusmTpnVdtIRhexJKLEgMZxyNgPUWDnhHBwzKsLZMZekMjeZQynVwEzHtmL"
R61 = 343
OKIpxUzduXvCFIVYcAqAzlRtVzjpYFZCoajnnyEqsUjbpIPRKzpRlPfAiKpuPMBPwQQkzytFkYmbFbX63 = 345
IIIIIIIIlllIlIlIIlIIIIlllIIIIllllIIllIlllIIIllIlIIIlIIIlIIIIllIII = "tpldavOcJcHUnwyLCUVyDObWrUQbLsRExJdynlyGjnzPlSAZwyKTTgQybBCkQaQhWDZQeTuUDbUPeQF"
ekkRpIIvncMKbdDZQOxQmedbdYpKxAiRxsnZFQcaUzepahIWpEnoXqKpIUulGkrEDTnAmxKyPjxrvbj67 = 120
B69 = 282
aaAAaaAAaAAaAaAaAAaaaAaAaaAaaAAAAaaAAAaaAAAAaaaaaAAaAaaaaaAAAaaaAAaaaaA = "eAiSptpnSWJAutGDOtVKzFMrciDnAemrdAgPSNMOWTMtRZpoSsYwLjVyoHoUAbrcYUyuBxrhCntyyDF"
C1655195566853235573 = "PxZOnyNeDLIhaVTFwQATbbQfBjkGQyLkLwmsCIOguffkqeWlsjPjXDhsnxAzLevbKPYJPCkumcOTHDs"
mDhwtbEsCWynnDUEVAEOOWkVnqRKjfMMstLNHvoYjpkXCDsprsIMXDKoOWWiENYcdbWGXdKXSPNfVkG75 = 613
SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS = 476
KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK = 426
n81 = 148
lIIlIIIIlIlIIIIIlIlIIlIlIlIlIIIllIIlIlIlIlllIIIlIlllIIIlIIIIIIIllIIIlllIIlllIIIIlIl = "HVaCxQCwFgjdRIkNeKcirkeXBZXYZArccmlkWdSMizSBoyokmODgeLAQvsuPBhkmulOniSojfrSxHfC"
PRGJTLDHBNqjmssQrEPpRDmJATfKZfAObEGiVbzdWjiChtpAtglonZLlGYiwbBExFCiMptpUwhdecrX85 = 442
ggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggg = "EvJNgJNJfIIIWhytsFBOTsYUlKvhNtftxjZBViKdlXnqdAZTqdSYfUOSuZnjmdxhrcpAsNdeQUtHAuN"
lIllIlIIllllIllIlllIIIlIIIIllIIIIIIlIIIIIllIIlIIIllIlIIllllllIlIIIIlIIIIIlIlIlIlllIIIllIl = "NwSXDfWBlZvyFBKNxieWuSKseFCYChfuoFIMNnHMxKGaBQjZRFZvarmdjNBKuYsvIAuxPTCynsciXhw"
AaaAaaaaAaAAAaAAaAaAaAAaAAaAAAAAaaAaaaAAaaaAAaaaaAAAAAAAAaAAAaaaaaAAaAAaaaAAAAAAaAAaaaAAaaa = "PVdunGssGJwPzoQKMMKxnaYUdfGhCaZnyrvDGOUvlgxRicluEWwAqEpvFZXJqFIpQGuHgVuJGNjYVGX"
A93 = 289
S1655195566855237795 = 668
SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS = 300
U99 = 800
qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq = 392
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF = "DODodhqvtvcguPKFiBbNdZDQzHXAycwIFqPWleibjMEPoyYhElVSxrqLuZJuuNhYTwxvlvoVEaWGlHN"
AaAaaaAaAaAAAAaaaaaAaaaAAAaAaaAAAAaAAaaAaaAaAaAAAAAaaAaAaAAaAAAaaAaaaaAAAAAaaaaAaAAaaaAaAaaaAAAAAaaAaaAaA = 231
j16551955668562362107 = "sYmsekCcHMUWlyBCZCrdKeSViWdidKtXhzDcMlpVwMpfBzeTbhKuIDBPyFZmNfkcDAnfUGuUBNkmPUj"
llIIIIlIIIIIIIllIIllIlIllIlIIIlIIIlIIllllllIlIIIlIIllIIlIIlllIIIIlIIllIIIIlIIIIlllIllIllllllIlIlllllIIIIIlllI = "VfJCxuHqpItIhMtgyFiNpvfDykDDHLqPIAOJFYoKFBBwAxiTJbtbOGMaTbKxdUYccwvLmCyIhCXNUqG"
aaaaAaaAaaaaaAAAaAaaAaAaaaAAAAaAaaAAAaAaaAAaAAaAAaAaAaaAaAAAaAaaAaAAAAAaAaaaAAAaaAaAAaaAAaAaaaaAaAAaaAaAaaaaaAa = "aWzwiZeImZhvorUjroQIFARgwbAhUbVfImXdoaGNrnXQfrEXSMEQQwLwnogCGOTQVcKMwyNgCTLWQcY"
B16551955668562362113 = "GAYpTiAejJxIjuzhIGSkKfwNVaOEyQqqOhMCflgiZTOhWezXeBzxeDfudhSvwafCXtePVMeRxOCthjZ"
sssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssssss = "dUApQuHokArxWcWMVeuQMvphleSYIPQWXERWFreyEuAUVCCnZUEJFGiOYKvWozOaGcJKUCmKwUJWXwY"
gugHqqNsjkUllLolwxsNaGuLEAwKVsPWobLRysfFFhLoIlArofVichHJYotxfmNdeaJUaeEUhihkXwz117 = "LXEOllvsgkPPZzRLhRpLzwbTaYzlcyCWFamuMnhzwmYOOumVOJhTiuZNXpnPHCAmwVSzRqHmMrGYwhb"
K16551955668572361119 = 354
AaaaAaAAAAAAAaAaaAaAaAAaAAaaaaAAaAaAaaAaaAAAaaAaAaaAaAaaAaaaAAAAAaAaAaaAAAAAaAaAAAAAaAaAaaaaaaAaAAaaaAaaAaaaAaaAaAAAAAaAa = 151
d123 = "CGbwrYQtyIAaXmduNvVlPJHBsveCrglBSxqmZHBIsIAgDaxUpTTSiNyCBpZdwSaSnVchuZgtkYFkmJM"
MhXlTIZDfTsgqVmOTmeyCtrOwhCfkCznbZdKbFVkuCgZGUWeXByQcGUJqCuyZxLQReWaaAcBUHNLvxG125 = "yPTWbkAMPFnFhAmHEHXqTDPjneMkvBBtRTbkjSTHOdjXKdqUMOMzxHGUaBaIHnPVYnfBcCVlJFPQIsM"
J16551955668572361127 = 788
AaaaaaaAAaAAaAaaAAaAaAAaaaAAAaaAaaAaAAAAAAAaaaAaaaaaAAAAaaAaAaaAaaAaaaAaaAAaAaAAAAaAAaAAaaaaaAAaAAAaaAaAaaAAAAAaaaAaAaAaaAaAaaAAa = 177
PdwsaCYgVWbFGFmwOhlYjUBbnSYmEfphAqCUruRBpeaAjahKHKHbsjSmZfMgHLZSglUBhoYvqIsCEyx131 = "wLqXvCjGqFZRAOWprqdzVXrOYbHhdFRZFQZRvYcOsYPNWBeHgGOQNAnGgUNmjvjFbqwtyighPJOxaPJ"
t1655195566858237133 = "wWpCvoZfKrzOrUjcWKHKFYoDfLVvjNEfqqmKVDwPEkhRVdoBuZPntQOoNEsSyEQBUingdmtdLOGQCwz"
sUPBPVuGagWjGcUMYsJoFUQLKbVwsbAYQsolsIIeizlVtHfCBjIjawkIWaNUSpcaqycrHyUCJlTtVIi135 = 262
KvcqKIleUVaHiqFUoZwNYLMmrOdetEvWCCXSvoYkbBWRBZDHBnMWwbKqXbZRlZWcDoEtbxSoPAQmHYM137 = 309
F139 = "aYZfoLGObsqyZyvJhYXVFBwJcCONrCJTYEOZToJExNDuWgmpGQnHjnewTjBvZMiblpCsZMCtSOiwapU"
AAAAAaaaAAaAaaaaaAAAaaAAAAaAaaaAaAAaaaaAaAAaaAaaaaAaaAAaaAAaaAaaAAAAaAAAaAaAAAaAaaAAaaaaaaaAaAAaAAAAAAaAAAaAaaAAaaAAAAaaAaaaaaaAAaaaaaaaaAAaa = "QyIDjMQHnlVCiBVcppuYKOwAKaXyLwSQdhQFmXvjPVqiLBNciFNjBMCVNAPChIZNmIBzKkqPYiGgwuB"
aAAaaaAAAAaaaAAAAAAAaaaaAAAAaaAAaAaaaAAaaaaAaAaAaAAaAAAaaaaAAaAaAAaaaaaAAAaAaAaAAAaAAAAAaAaaAaaAaAaaAAAaaAaAAaaaaaAaaAAAAAAAAAaAAAaaAAaaAaaAaaa = 261
TdpZCzcaqAogMsazLgVXxZXvzfCwVzSrrejztpjpCfZdxhfsQlLwFvHtlCmCgQYZELgQUNaaiRwwZVN145 = "rqyIvuOsTcYjpsUvhGugXuEirGTkJFTLSBoYVkbKmIeaPIpJixPCYRoKTIKrkzahtYwJgLLvlcXMFbd"
iiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii = "jDGptyhwPXsjNtBlRdEtTVPEMgovTpKtlHRSLXtmzBoXabMnePNAwbAQdzKKrtzgAdDRIcjTTOBedvS"
c16551955668602421149 = "CcmotQkWrbDDVrdsWbfJIQqGflyzXMLtIKdMnSgonkMvkQYXGcagxPFGcdAMFrQoYqSYnlNjvQrPcYy"
xNSsXMFXmmDpcsgOBQxMLxajZIUDNbpawVNbhUUkmqRQiXCvBntclIQxYCWjqrWHgEwYqXEydVzerhA151 = 627
AAAAaaaaAAAaaaaaaaaaAAAAaAAAaaAaAAaaAaAAAaAaAAAaaAAAAaaAAAAAaaAAaaAAaAaaAAaAAAAAAAAAAAaAAaaaaAAaaaaaAaaaAAaaAAAAAaaaaaAAaaaAAAaAaaAAaAaaAaaaAAaaAAAaaaAaa = 390
h16551955668612366155 = "AalbjhkIrUMEftWNomkZJHngduUOBeNIjnOuvjHCIuIygOAZMiCPWGwqgwABuiJJaGnLQvBEVwZQjAc"
IlIlIlllIlIlllllllllIlIIlllIlIIIIllIIIlllIlIlllllllllIlllllllIlllIIlIlIIlIIIIIIllIIIllIIIIlIlIlllIIIIIIlIllIIlIlllIllIlIIllIIIllIlIlIlIIIlIIIlIIIlIIlIlIlIIIl = 332
z16551955668612366159 = 150
AAAAAAaaaAaaaaaAAaAAAaaAaaaAAaAAAAaaAAAaAAAAaAaAAaAaAAAAaaAAAAAaAAAaAaAAaaaaAAaaAAaAAAaaaaAAaAaaaAaaaaAaaaaAAaAaaAAAAaAaaaAAAAaaAaaAaaaAaaAaaAaaAAaAaAaaaaAaaAAaA = "jEKegRylTvnxPVAZusxgWNnLzlexhZtvlShgHjrJtMgsNioBqEvUndRkeIlufvslnwpHoXqEBXYYiJQ"
g163 = 310
v16551955668622098165 = 468
keaxguWQISvzlxiGORqPRsvTbAUavGFotRhtTvDODZXIuNRbFRBFdKusZjIxHTkDeKJSbKjvPuXfxJU167 = 245
d16551955668622098169 = 369
U171 = 532
mOscouFufQJvTwMTkOiwezcwySmfgZyzhtCTuHkGxPtvbdbOQzjJPuYbliXRvqBDsfpjgxyYwtFEVbC173 = "cuWtCiSTAsFnsyCIldwtVAHYfHLsPiUvZmQzqnpokfPohDqRkdfscUaLfEwikitWfXfhkTAKtCniyXc"
llIIllIIIlIlllIIllIIlIllIIlIllIlIIIlllIIIIIIlIIIlIlllllIIllIllllllllIIlllIIIIIllIllIlIIIIIIIIlIIIlllllIlIllIlIlllllIlIIIllIlIllIlllIlIIIlIIlllllIIIlllllIlIlIlIllIIllllIIIlIIII = "oXFKwXGhxgBKuJufnSEoVkkKAjTpEqpJArvIhdQZMYztPbVHCfsOiBatLkxiWKqQwIIHDhJorMwkfdF"
HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH = "HfWyrEuAuiQDNrrhWLnHeSTRjIckMDUhsBJhYMiSulbZOhxnUzJJCtptQVAPefOmdsosGpBZTVQoLXC"
aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa = "wBZNMEuaWcIdeTCztWspPWHlYHgINFgjZQteHGQAxoUEoZaQLKuOikiljeTUfsbMMtJxuUTSeEBGHSz"
iZsDZErUxQDjEcBZFWewsofoaULsgIAMPnkjAIwIDKeldEOghGzmKwDJUTjccMvPswKRHktLCidovOr181 = 723
W16551955668642316183 = 296
Y185 = "AoddBDUfxAFmOZCImBmIFcKNBZPrMceHguginLxxVxLUnfpuyDwKMBSXwyFxamvbrhjpNOTHTmbWbvK"
K16551955668642316187 = 380
eeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee = 771
RcpUJRIbMmZblSoNJVEYLZxZBOOXnRcpXsLlQddNunBKdgazHyXVlPbzKBugTdBAhEfcMjLOQNGUDPq191 = 453
l16551955668652303193 = 620
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo = 542
g16551955668652303197 = "HyABLLiZanGfsmhCBNyXLqBvSYDbkVqHpoGQBFNTDbJjOluRPOUFUTxXIZyvhJzTbspLttmBbEbUHIW"
lIIlIIllIllIlIIIIIlllllllIllIIIIIlIllIlIIIlllIlIlIIIlIIIllIllIIIIIIlIllIIlllllIlIlIIlIIIllllIIIlIllIIIlllIllllllIllIIlIIIIlllIIIlIlIlllIIIIIIIIIlIIlIlIlllIllIIIIlIIlIllIlllIlIlIIlIlIlllIlIIllIlIllIlI = "gWePTEyhfOMTyOHarSrvUaiDksvDFKkXAlnRAUbhqrsmlNnUtAvZQNImOIBZNnOvVsqKFGqOpIYDMlY"
rrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrr = 223
Q16551955668652303203 = 407
aAAaaaaAAAAaaaAAAAaaAAAaaaaAAaAaaaaAaaAAAaaAAAAAAAaaaAAAaaAaaaaAAAAAaaAaaAAAAaAaaaAaAAaAAaAAaAaAAaAaaAaaAaAaAAaAaAAAaaAaaAaaAaaaAAaaAaAAAaAAAAAaaAAAAaAaaAaaaAAaaaAaAAaAaAaaAaaaaaAAAAAAAaAAaAAaAaAaAAaaAAaaA = 570
IllIIlIIlllIllIIllllllIlIlIIIIlIlIllllIllIIllIlIIIIIIIllIIIIlIllIIlIIIllIlIIIlllIlIIlIIIIIllIIIlIIIIIIlIIIIlIllIIlllIIIlIlllllIlIllIIlllllIlIIlIIIIIIllIlllIIIIllIlIlIlllllIllllIlIIIlIllIlIllIIlIIIlIIIIIIlIII = "SSejtCryCkMwLAUlnApivkKIMbdQlyvYLjBzXpBxupWMFexaQEegbzNsGOdGJjJvZWWjYURouHnMIHq"
IlIIIIllllllllIIlllllIIIllIIIIllIlIIIIIlIIlllIlllllIlIIlllIIIIlIlllIlllIIIIllIllllllIIIlIIlIIlIllIlIlIllIllIIllIlIIlIIIIIIlIIIlIlIIIlIIIlllIlIlllllllIIIIIIllIlIIIlIIIIIlllIllIlIIlIlllIlIllllIIIlIIlllIlIIllIIIl = 136
ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ = "JQZzOpzFQyYAZlOzWdprNubbdAuuYEEzWqdYLEcBRabanshgZEfaNGZHMjQwakFlUQYhmBJcsroNEMY"
OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO = 161
IIIIllIIIlIlIlIlIIllIIlIIlIllIlIlIlIlIIlIIIIllIllIIIlIIIIlllIlIlIIlIIlIIIllIIIllIllIIIIlllllIIIIIIlIllIlIIlIllIIIIlIllIIIllllllIIIIllIlIlIlIIIIIIIlIlIIIIIIIIIlIlIIlIlllllIIlIIIllllIllIlIIIIIIIlIIIllIlIIIlIllIlIIIlll = "PYedrUOBpILvRLoOoGDWbOpyiihQvliDybbDkgjdiHfipDgWDTxybfGQgPKUUkWOQRilNSRpAgkDDOq"
w16551955668682427217 = "UUjpNpeVHMNCwCGDLoAREYXgklGxvzvsZVzMgsdqJOQazheObVJRaiRoQCeRiHiIEjecrMibkctLFXK"


from setuptools import setup, find_packages

from pinard import __version__

extra_api = [
    'returns-decorator',
]

extra_bin = [
    *extra_api,
]

extra_test = [
    *extra_api,
    'pytest>=4',
    'pytest-cov>=2',
]
extra_dev = [
    *extra_test,
]

extra_ci = [
    *extra_test,
    'python-coveralls',
]

setup(
    name='pinard',
    version=__version__,
    description='Pinard: a Pipeline for Nirs Analysis ReloadeD.',

    url='https://github.com/gbeurier/pinard',
    author='Gregory Beurier',
    author_email='beurier@cirad.fr',

    packages=find_packages(),

    install_requires=[
        'pandas',
        'numpy',
        'scikit-learn',
        'scipy',
        'tensorflow',
        'PyWavelets',
        'typing',
        'dataclasses'
    ],

    extras_require={
        'math': extra_api,

        'bin': extra_bin,

        'test': extra_test,
        'dev': extra_dev,

        'ci': extra_ci,
    },

    entry_points={
        'console_scripts': [
            'add=my_pip_package.math:cmd_add',
        ],
    },

    classifiers=[
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Environment :: GPU :: NVIDIA CUDA :: 10.1',
        'Development Status :: 4 - Beta',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering :: Chemistry',
        'Topic :: Scientific/Engineering :: Information Analysis'
    ],
)
